"""__init__.py"""
__all__ = ['__version__', '__author__', '__description__']
__version__ = '1.0a0.dev3'
__author__ = 'Lacides Miranda'
__description__ = 'WHDLoad is a collection of Amiga Roms'
__prefix__ = 'whdload'
